aboutsummaryrefslogtreecommitdiffstats
path: root/OpenAL32
diff options
context:
space:
mode:
authorChris Robinson <[email protected]>2011-09-25 11:32:51 -0700
committerChris Robinson <[email protected]>2011-09-25 11:32:51 -0700
commit8a0e0265bc5675fe810aae8ee2bbcdd7a29d82c1 (patch)
treea2db635a49415b9fd75fe8f93cf8cbb48e292052 /OpenAL32
parent0ada7b2da5440316cd48fb143fa7472b0bb09bc8 (diff)
Clamp the low-pass reference gain to -60 dB instead of -40 dB
Diffstat (limited to 'OpenAL32')
-rw-r--r--OpenAL32/alFilter.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/OpenAL32/alFilter.c b/OpenAL32/alFilter.c
index 07cc1ea3..5697b868 100644
--- a/OpenAL32/alFilter.c
+++ b/OpenAL32/alFilter.c
@@ -348,11 +348,11 @@ ALfloat lpCoeffCalc(ALfloat g, ALfloat cw)
{
ALfloat a = 0.0f;
/* Be careful with gains < 0.01, as that causes the coefficient
* head towards 1, which will flatten the signal */
if(g < 0.9999f) /* 1-epsilon */
{
- g = maxf(g, 0.01f);
+ g = maxf(g, 0.001f);
a = (1 - g*cw - aluSqrt(2*g*(1-cw) - g*g*(1 - cw*cw))) /
(1 - g);
}
@@ -348,11 +348,11 @@ ALfloat lpCoeffCalc(ALfloat g, ALfloat cw)
{
ALfloat a = 0.0f;
- /* Be careful with gains < 0.01, as that causes the coefficient
- * head towards 1, which will flatten the signal */
+ /* Be careful with gains < 0.001, as that causes the coefficient head
+ * towards 1, which will flatten the signal */
if(g < 0.9999f) /* 1-epsilon */
{